[gnome-builder/wip/gtk4-port] plugins/xml-pack: make plugin compile



commit bc9dfae01ae8ea5280dbbc3d0f677b1230ba14a4
Author: Christian Hergert <chergert redhat com>
Date:   Wed Apr 20 18:07:19 2022 -0700

    plugins/xml-pack: make plugin compile
    
    This disables the indenter/completion bits still, but it's a start to at
    least get things moving further.

 src/plugins/meson.build                            |  2 +-
 src/plugins/xml-pack/ide-xml-completion-provider.c | 80 +++++++++++-----------
 src/plugins/xml-pack/ide-xml-completion-values.c   |  8 +--
 src/plugins/xml-pack/ide-xml-hash-table.c          |  5 +-
 src/plugins/xml-pack/ide-xml-highlighter.c         | 34 ++++-----
 src/plugins/xml-pack/ide-xml-indenter.c            | 22 +++---
 src/plugins/xml-pack/ide-xml-parser-ui.c           | 49 +++++++------
 src/plugins/xml-pack/ide-xml-parser.c              | 15 ++--
 src/plugins/xml-pack/ide-xml-position.c            |  8 +--
 src/plugins/xml-pack/ide-xml-proposal.c            |  2 +-
 src/plugins/xml-pack/ide-xml-rng-define.c          |  8 +--
 src/plugins/xml-pack/ide-xml-rng-parser.c          | 61 ++++++++---------
 src/plugins/xml-pack/ide-xml-service.c             | 22 +++---
 src/plugins/xml-pack/ide-xml-stack.c               |  3 +-
 src/plugins/xml-pack/ide-xml-tree-builder-utils.c  |  5 +-
 src/plugins/xml-pack/ide-xml-tree-builder.c        | 14 ++--
 src/plugins/xml-pack/meson.build                   |  4 +-
 src/plugins/xml-pack/xml-pack-plugin.c             |  9 ++-
 18 files changed, 170 insertions(+), 181 deletions(-)
---
diff --git a/src/plugins/meson.build b/src/plugins/meson.build
index 3515a7479..839cf2112 100644
--- a/src/plugins/meson.build
+++ b/src/plugins/meson.build
@@ -139,7 +139,7 @@ subdir('vim')
 subdir('vls')
 subdir('waf')
 subdir('words')
-#subdir('xml-pack')
+subdir('xml-pack')
 
 plugins = static_library('plugins', plugins_sources,
          dependencies: plugins_deps,
diff --git a/src/plugins/xml-pack/ide-xml-completion-provider.c 
b/src/plugins/xml-pack/ide-xml-completion-provider.c
index eece5ff61..c04b015e7 100644
--- a/src/plugins/xml-pack/ide-xml-completion-provider.c
+++ b/src/plugins/xml-pack/ide-xml-completion-provider.c
@@ -80,14 +80,14 @@ typedef struct
   IdeXmlRngDefine *define;
 } CompletionItem;
 
-static void      completion_provider_init (IdeCompletionProviderInterface *iface);
-static gboolean  process_matching_state   (MatchingState                  *state,
-                                           IdeXmlRngDefine                *define);
+static void      completion_provider_init (GtkSourceCompletionProviderInterface *iface);
+static gboolean  process_matching_state   (MatchingState                        *state,
+                                           IdeXmlRngDefine                      *define);
 
 G_DEFINE_FINAL_TYPE_WITH_CODE (IdeXmlCompletionProvider,
-                         ide_xml_completion_provider,
-                         IDE_TYPE_OBJECT,
-                         G_IMPLEMENT_INTERFACE (IDE_TYPE_COMPLETION_PROVIDER, completion_provider_init))
+                               ide_xml_completion_provider,
+                               IDE_TYPE_OBJECT,
+                               G_IMPLEMENT_INTERFACE (GTK_SOURCE_TYPE_COMPLETION_PROVIDER, 
completion_provider_init))
 
 static void
 populate_state_free (PopulateState *state)
@@ -936,7 +936,7 @@ populate_cb (GObject      *object,
   if (ide_task_return_error_if_cancelled (task))
     return;
 
-  proposals = g_list_store_new (IDE_TYPE_COMPLETION_PROPOSAL);
+  proposals = g_list_store_new (GTK_SOURCE_TYPE_COMPLETION_PROPOSAL);
 
   analysis = ide_xml_position_get_analysis (position);
   schemas = ide_xml_analysis_get_schemas (analysis);
@@ -1024,8 +1024,8 @@ cleanup:
 }
 
 static void
-ide_xml_completion_provider_populate_async (IdeCompletionProvider *provider,
-                                            IdeCompletionContext  *context,
+ide_xml_completion_provider_populate_async (GtkSourceCompletionProvider *provider,
+                                            GtkSourceCompletionContext  *context,
                                             GCancellable          *cancellable,
                                             GAsyncReadyCallback    callback,
                                             gpointer               user_data)
@@ -1039,7 +1039,7 @@ ide_xml_completion_provider_populate_async (IdeCompletionProvider *provider,
   GtkTextIter iter;
 
   g_assert (IDE_IS_XML_COMPLETION_PROVIDER (self));
-  g_assert (IDE_IS_COMPLETION_CONTEXT (context));
+  g_assert (GTK_SOURCE_IS_COMPLETION_CONTEXT (context));
   g_assert (!cancellable || G_IS_CANCELLABLE (cancellable));
 
   task = ide_task_new (self, cancellable, callback, user_data);
@@ -1048,8 +1048,8 @@ ide_xml_completion_provider_populate_async (IdeCompletionProvider *provider,
   ide_context = ide_object_get_context (IDE_OBJECT (self));
   service = ide_xml_service_from_context (ide_context);
 
-  buffer = ide_completion_context_get_buffer (context);
-  ide_completion_context_get_bounds (context, &iter, NULL);
+  buffer = gtk_source_completion_context_get_buffer (context);
+  gtk_source_completion_context_get_bounds (context, &iter, NULL);
 
   state = g_slice_new0 (PopulateState);
   state->file = g_object_ref (ide_buffer_get_file (IDE_BUFFER (buffer)));
@@ -1069,7 +1069,7 @@ ide_xml_completion_provider_populate_async (IdeCompletionProvider *provider,
 }
 
 static GListModel *
-ide_xml_completion_provider_populate_finish (IdeCompletionProvider  *provider,
+ide_xml_completion_provider_populate_finish (GtkSourceCompletionProvider  *provider,
                                              GAsyncResult           *result,
                                              GError                **error)
 {
@@ -1080,8 +1080,8 @@ ide_xml_completion_provider_populate_finish (IdeCompletionProvider  *provider,
 }
 
 static gboolean
-ide_xml_completion_provider_refilter (IdeCompletionProvider *provider,
-                                      IdeCompletionContext  *context,
+ide_xml_completion_provider_refilter (GtkSourceCompletionProvider *provider,
+                                      GtkSourceCompletionContext  *context,
                                       GListModel            *model)
 {
   g_autofree gchar *word = NULL;
@@ -1089,11 +1089,11 @@ ide_xml_completion_provider_refilter (IdeCompletionProvider *provider,
   guint n_items;
 
   g_assert (IDE_IS_XML_COMPLETION_PROVIDER (provider));
-  g_assert (IDE_IS_COMPLETION_CONTEXT (context));
+  g_assert (GTK_SOURCE_IS_COMPLETION_CONTEXT (context));
   g_assert (G_IS_LIST_MODEL (model));
 
   n_items = g_list_model_get_n_items (model);
-  word = ide_completion_context_get_word (context);
+  word = gtk_source_completion_context_get_word (context);
   casefold = g_utf8_casefold (word, -1);
 
   /* TODO: This doesn't work with backspace. We need to track things
@@ -1106,7 +1106,7 @@ ide_xml_completion_provider_refilter (IdeCompletionProvider *provider,
       const gchar *label = ide_xml_proposal_get_label (proposal);
       guint priority;
 
-      if (!ide_completion_fuzzy_match (label, casefold, &priority))
+      if (!gtk_source_completion_fuzzy_match (label, casefold, &priority))
         g_list_store_remove (G_LIST_STORE (model), i - 1);
     }
 
@@ -1114,33 +1114,31 @@ ide_xml_completion_provider_refilter (IdeCompletionProvider *provider,
 }
 
 static void
-ide_xml_completion_provider_display_proposal (IdeCompletionProvider   *provider,
-                                              IdeCompletionListBoxRow *row,
-                                              IdeCompletionContext    *context,
-                                              const gchar             *typed_text,
-                                              IdeCompletionProposal   *proposal)
+ide_xml_completion_provider_display (GtkSourceCompletionProvider *provider,
+                                     GtkSourceCompletionContext  *context,
+                                     GtkSourceCompletionProposal *proposal,
+                                     GtkSourceCompletionCell     *cell)
 {
   IdeXmlProposal *item = (IdeXmlProposal *)proposal;
   const gchar *label;
 
   g_assert (IDE_IS_XML_COMPLETION_PROVIDER (provider));
-  g_assert (IDE_IS_COMPLETION_LIST_BOX_ROW (row));
-  g_assert (IDE_IS_COMPLETION_CONTEXT (context));
-  g_assert (IDE_IS_COMPLETION_PROPOSAL (proposal));
+  g_assert (GTK_SOURCE_IS_COMPLETION_LIST_BOX_ROW (row));
+  g_assert (GTK_SOURCE_IS_COMPLETION_CONTEXT (context));
+  g_assert (GTK_SOURCE_IS_COMPLETION_PROPOSAL (proposal));
 
   label = ide_xml_proposal_get_label (item);
 
-  ide_completion_list_box_row_set_icon_name (row, NULL);
-  ide_completion_list_box_row_set_left (row, NULL);
-  ide_completion_list_box_row_set_right (row, NULL);
-  ide_completion_list_box_row_set_center_markup (row, label);
+  gtk_source_completion_list_box_row_set_icon_name (row, NULL);
+  gtk_source_completion_list_box_row_set_left (row, NULL);
+  gtk_source_completion_list_box_row_set_right (row, NULL);
+  gtk_source_completion_list_box_row_set_center_markup (row, label);
 }
 
 static void
-ide_xml_completion_provider_activate_proposal (IdeCompletionProvider *provider,
-                                               IdeCompletionContext  *context,
-                                               IdeCompletionProposal *proposal,
-                                               const GdkEventKey     *key)
+ide_xml_completion_provider_activate (GtkSourceCompletionProvider *provider,
+                                      GtkSourceCompletionContext  *context,
+                                      GtkSourceCompletionProposal *proposal)
 {
   IdeXmlProposal *item = (IdeXmlProposal *)proposal;
   GtkTextBuffer *buffer;
@@ -1148,13 +1146,13 @@ ide_xml_completion_provider_activate_proposal (IdeCompletionProvider *provider,
   const gchar *text;
 
   g_assert (IDE_IS_XML_COMPLETION_PROVIDER (provider));
-  g_assert (IDE_IS_COMPLETION_CONTEXT (context));
-  g_assert (IDE_IS_COMPLETION_PROPOSAL (proposal));
+  g_assert (GTK_SOURCE_IS_COMPLETION_CONTEXT (context));
+  g_assert (GTK_SOURCE_IS_COMPLETION_PROPOSAL (proposal));
 
   text = ide_xml_proposal_get_text (item);
 
-  buffer = ide_completion_context_get_buffer (context);
-  ide_completion_context_get_bounds (context, &begin, &end);
+  buffer = gtk_source_completion_context_get_buffer (context);
+  gtk_source_completion_context_get_bounds (context, &begin, &end);
 
   gtk_text_buffer_begin_user_action (buffer);
   gtk_text_buffer_delete (buffer, &begin, &end);
@@ -1182,10 +1180,10 @@ ide_xml_completion_provider_init (IdeXmlCompletionProvider *self)
 }
 
 static void
-completion_provider_init (IdeCompletionProviderInterface *iface)
+completion_provider_init (GtkSourceCompletionProviderInterface *iface)
 {
-  iface->activate_proposal = ide_xml_completion_provider_activate_proposal;
-  iface->display_proposal = ide_xml_completion_provider_display_proposal;
+  iface->activate = ide_xml_completion_provider_activate;
+  iface->display = ide_xml_completion_provider_display;
   iface->populate_async = ide_xml_completion_provider_populate_async;
   iface->populate_finish = ide_xml_completion_provider_populate_finish;
   iface->refilter = ide_xml_completion_provider_refilter;
diff --git a/src/plugins/xml-pack/ide-xml-completion-values.c 
b/src/plugins/xml-pack/ide-xml-completion-values.c
index 51e7c3216..c3e871178 100644
--- a/src/plugins/xml-pack/ide-xml-completion-values.c
+++ b/src/plugins/xml-pack/ide-xml-completion-values.c
@@ -18,8 +18,6 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
-#include <dazzle.h>
-
 #include "ide-xml-completion-values.h"
 #include "ide-xml-position.h"
 
@@ -40,7 +38,7 @@ value_match_item_new (const gchar *value)
 {
   ValueMatchItem *item;
 
-  g_assert (!dzl_str_empty0 (value));
+  g_assert (!ide_str_empty0 (value));
 
   item = g_slice_new0 (ValueMatchItem);
   item->name = g_strdup (value);
@@ -125,8 +123,8 @@ process_value (MatchingState *state)
 
   value = (gchar *)state->define->name;
 
-  if (!dzl_str_empty0 (value) &&
-      (dzl_str_empty0 (state->prefix) || g_str_has_prefix (value, state->prefix)))
+  if (!ide_str_empty0 (value) &&
+      (ide_str_empty0 (state->prefix) || g_str_has_prefix (value, state->prefix)))
     {
       match_values = match_values_new ();
       item = value_match_item_new (value);
diff --git a/src/plugins/xml-pack/ide-xml-hash-table.c b/src/plugins/xml-pack/ide-xml-hash-table.c
index 108920116..f763b1dc9 100644
--- a/src/plugins/xml-pack/ide-xml-hash-table.c
+++ b/src/plugins/xml-pack/ide-xml-hash-table.c
@@ -18,7 +18,6 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
-#include <dazzle.h>
 #include <libide-code.h>
 
 #include "ide-xml-hash-table.h"
@@ -103,7 +102,7 @@ ide_xml_hash_table_add (IdeXmlHashTable *self,
   GPtrArray *array;
 
   g_return_val_if_fail (self != NULL, FALSE);
-  g_return_val_if_fail (!dzl_str_empty0 (name), FALSE);
+  g_return_val_if_fail (!ide_str_empty0 (name), FALSE);
   g_return_val_if_fail (data != NULL, FALSE);
 
   if (NULL == (array = g_hash_table_lookup (self->table, name)))
@@ -130,7 +129,7 @@ ide_xml_hash_table_lookup (IdeXmlHashTable *self,
                            const gchar     *name)
 {
   g_return_val_if_fail (self != NULL, NULL);
-  g_return_val_if_fail (!dzl_str_empty0 (name), NULL);
+  g_return_val_if_fail (!ide_str_empty0 (name), NULL);
 
   return g_hash_table_lookup (self->table, name);
 }
diff --git a/src/plugins/xml-pack/ide-xml-highlighter.c b/src/plugins/xml-pack/ide-xml-highlighter.c
index b1fe30835..99d1111ba 100644
--- a/src/plugins/xml-pack/ide-xml-highlighter.c
+++ b/src/plugins/xml-pack/ide-xml-highlighter.c
@@ -22,7 +22,6 @@
 
 #include "config.h"
 
-#include <dazzle.h>
 #include <glib/gi18n.h>
 
 #include "ide-xml.h"
@@ -35,7 +34,7 @@ struct _IdeXmlHighlighter
 {
   IdeObject           parent_instance;
   IdeHighlightEngine *engine;
-  DzlSignalGroup     *buffer_signals;
+  IdeSignalGroup     *buffer_signals;
   guint               highlight_timeout;
   guint               has_tags : 1;
 };
@@ -43,9 +42,9 @@ struct _IdeXmlHighlighter
 static void highlighter_iface_init (IdeHighlighterInterface *iface);
 
 G_DEFINE_FINAL_TYPE_WITH_CODE (IdeXmlHighlighter,
-                         ide_xml_highlighter,
-                         IDE_TYPE_OBJECT,
-                         G_IMPLEMENT_INTERFACE (IDE_TYPE_HIGHLIGHTER, highlighter_iface_init))
+                               ide_xml_highlighter,
+                               IDE_TYPE_OBJECT,
+                               G_IMPLEMENT_INTERFACE (IDE_TYPE_HIGHLIGHTER, highlighter_iface_init))
 
 static gboolean
 ide_xml_highlighter_highlight_timeout_handler (gpointer data)
@@ -127,14 +126,14 @@ ide_xml_highlighter_cursor_moved (IdeXmlHighlighter *self,
   g_assert (IDE_IS_XML_HIGHLIGHTER (self));
   g_assert (IDE_IS_BUFFER (buffer));
 
-  dzl_clear_source (&self->highlight_timeout);
+  g_clear_handle_id (&self->highlight_timeout, g_source_remove);
 
   self->highlight_timeout =
-    gdk_threads_add_timeout_full (G_PRIORITY_LOW,
-                                  HIGHLIGH_TIMEOUT_MSEC,
-                                  ide_xml_highlighter_highlight_timeout_handler,
-                                  g_object_ref (self),
-                                  g_object_unref);
+    g_timeout_add_full (G_PRIORITY_LOW,
+                        HIGHLIGH_TIMEOUT_MSEC,
+                        ide_xml_highlighter_highlight_timeout_handler,
+                        g_object_ref (self),
+                        g_object_unref);
 }
 
 static void
@@ -142,7 +141,7 @@ ide_xml_highlighter_dispose (GObject *object)
 {
   IdeXmlHighlighter *self = (IdeXmlHighlighter *)object;
 
-  dzl_clear_source (&self->highlight_timeout);
+  g_clear_handle_id (&self->highlight_timeout, g_source_remove);
   g_clear_object (&self->buffer_signals);
 
   G_OBJECT_CLASS (ide_xml_highlighter_parent_class)->dispose (object);
@@ -159,9 +158,9 @@ ide_xml_highlighter_class_init (IdeXmlHighlighterClass *klass)
 static void
 ide_xml_highlighter_init (IdeXmlHighlighter *self)
 {
-  self->buffer_signals = dzl_signal_group_new (IDE_TYPE_BUFFER);
+  self->buffer_signals = ide_signal_group_new (IDE_TYPE_BUFFER);
 
-  dzl_signal_group_connect_object (self->buffer_signals,
+  ide_signal_group_connect_object (self->buffer_signals,
                                    "cursor-moved",
                                    G_CALLBACK (ide_xml_highlighter_cursor_moved),
                                    self,
@@ -182,14 +181,11 @@ ide_xml_highlighter_real_set_engine (IdeHighlighter     *highlighter,
 
   if (engine != NULL)
     {
-      GtkTextIter insert;
-
       buffer = ide_highlight_engine_get_buffer (engine);
-      ide_buffer_get_selection_bounds (buffer, &insert, NULL);
-      ide_xml_highlighter_cursor_moved (self, &insert, buffer);
+      ide_xml_highlighter_cursor_moved (self, buffer);
     }
 
-  dzl_signal_group_set_target (self->buffer_signals, buffer);
+  ide_signal_group_set_target (self->buffer_signals, buffer);
 }
 
 static void
diff --git a/src/plugins/xml-pack/ide-xml-indenter.c b/src/plugins/xml-pack/ide-xml-indenter.c
index 0c65ca091..f855a0293 100644
--- a/src/plugins/xml-pack/ide-xml-indenter.c
+++ b/src/plugins/xml-pack/ide-xml-indenter.c
@@ -36,10 +36,10 @@ struct _IdeXmlIndenter
   guint use_tabs : 1;
 };
 
-static void indenter_iface_init (IdeIndenterInterface *iface);
+static void indenter_iface_init (GtkSourceIndenterInterface *iface);
 
 G_DEFINE_FINAL_TYPE_WITH_CODE (IdeXmlIndenter, ide_xml_indenter, IDE_TYPE_OBJECT,
-                         G_IMPLEMENT_INTERFACE (IDE_TYPE_INDENTER, indenter_iface_init))
+                               G_IMPLEMENT_INTERFACE (GTK_SOURCE_TYPE_INDENTER, indenter_iface_init))
 
 static gunichar
 text_iter_peek_next_char (const GtkTextIter *location)
@@ -371,8 +371,8 @@ ide_xml_indenter_maybe_add_closing (IdeXmlIndenter *xml,
 }
 
 static gboolean
-ide_xml_indenter_is_trigger (IdeIndenter *indenter,
-                             GdkEventKey *event)
+ide_xml_indenter_is_trigger (GtkSourceIndenter *indenter,
+                             GdkEventKey       *event)
 {
   switch (event->keyval)
     {
@@ -390,12 +390,12 @@ ide_xml_indenter_is_trigger (IdeIndenter *indenter,
 }
 
 static gchar *
-ide_xml_indenter_format (IdeIndenter *indenter,
-                         GtkTextView *view,
-                         GtkTextIter *begin,
-                         GtkTextIter *end,
-                         gint        *cursor_offset,
-                         GdkEventKey *trigger)
+ide_xml_indenter_format (GtkSourceIndenter *indenter,
+                         GtkTextView       *view,
+                         GtkTextIter       *begin,
+                         GtkTextIter       *end,
+                         gint              *cursor_offset,
+                         GdkEventKey       *trigger)
 {
   IdeXmlIndenter *xml = (IdeXmlIndenter *)indenter;
   guint tab_width = 2;
@@ -447,7 +447,7 @@ ide_xml_indenter_format (IdeIndenter *indenter,
 }
 
 static void
-indenter_iface_init (IdeIndenterInterface *iface)
+indenter_iface_init (GtkSourceIndenterInterface *iface)
 {
   iface->format = ide_xml_indenter_format;
   iface->is_trigger = ide_xml_indenter_is_trigger;
diff --git a/src/plugins/xml-pack/ide-xml-parser-ui.c b/src/plugins/xml-pack/ide-xml-parser-ui.c
index 5c77695f4..9550a42a2 100644
--- a/src/plugins/xml-pack/ide-xml-parser-ui.c
+++ b/src/plugins/xml-pack/ide-xml-parser-ui.c
@@ -20,7 +20,6 @@
 
 #define G_LOG_DOMAIN "ide-xml-parser-ui"
 
-#include <dazzle.h>
 #include <libide-code.h>
 
 #include "ide-xml-parser-ui.h"
@@ -37,7 +36,7 @@ get_attribute (const guchar **list,
   const gchar *value = NULL;
 
   value = list_get_attribute (list, name);
-  return dzl_str_empty0 (value) ? ((replacement != NULL) ? replacement : NULL) : value;
+  return ide_str_empty0 (value) ? ((replacement != NULL) ? replacement : NULL) : value;
 }
 
 static void
@@ -64,10 +63,10 @@ ide_xml_parser_ui_start_element_sax_cb (ParserState    *state,
   string = g_string_new (NULL);
   parent_name = ide_xml_symbol_node_get_element_name (state->parent_node);
 
-  if (dzl_str_equal0 (name, "property"))
+  if (ide_str_equal0 (name, "property"))
     {
-      if (dzl_str_equal0 (parent_name, "object") ||
-          dzl_str_equal0 (parent_name, "template"))
+      if (ide_str_equal0 (parent_name, "object") ||
+          ide_str_equal0 (parent_name, "template"))
         {
           value = get_attribute (attributes, "name", NULL);
           node = ide_xml_symbol_node_new (value, NULL, "property", IDE_SYMBOL_KIND_UI_PROPERTY);
@@ -75,11 +74,11 @@ ide_xml_parser_ui_start_element_sax_cb (ParserState    *state,
           state->build_state = BUILD_STATE_GET_CONTENT;
         }
     }
-  else if (dzl_str_equal0 (name, "attribute"))
+  else if (ide_str_equal0 (name, "attribute"))
     {
-      if (dzl_str_equal0 (parent_name, "section") ||
-          dzl_str_equal0 (parent_name, "submenu") ||
-          dzl_str_equal0 (parent_name, "item"))
+      if (ide_str_equal0 (parent_name, "section") ||
+          ide_str_equal0 (parent_name, "submenu") ||
+          ide_str_equal0 (parent_name, "item"))
         {
           value = get_attribute (attributes, "name", NULL);
           node = ide_xml_symbol_node_new (value, NULL, "attribute", IDE_SYMBOL_KIND_UI_MENU_ATTRIBUTE);
@@ -87,13 +86,13 @@ ide_xml_parser_ui_start_element_sax_cb (ParserState    *state,
           state->build_state = BUILD_STATE_GET_CONTENT;
         }
     }
-  else if (dzl_str_equal0 (name, "class") && dzl_str_equal0 (parent_name, "style"))
+  else if (ide_str_equal0 (name, "class") && ide_str_equal0 (parent_name, "style"))
     {
       value = get_attribute (attributes, "name", NULL);
       node = ide_xml_symbol_node_new (value, NULL, "class", IDE_SYMBOL_KIND_UI_STYLE_CLASS);
       is_internal = TRUE;
     }
-  else if (dzl_str_equal0 (name, "child"))
+  else if (ide_str_equal0 (name, "child"))
     {
       g_string_append (string, "child");
 
@@ -114,7 +113,7 @@ ide_xml_parser_ui_start_element_sax_cb (ParserState    *state,
       node = ide_xml_symbol_node_new (string->str, NULL, "child", IDE_SYMBOL_KIND_UI_CHILD);
       g_object_set (node, "use-markup", TRUE, NULL);
     }
-  else if (dzl_str_equal0 (name, "object"))
+  else if (ide_str_equal0 (name, "object"))
     {
       value = get_attribute (attributes, "class", "?");
       label = ide_xml_parser_get_color_tag (self, "class", COLOR_TAG_CLASS, TRUE, TRUE, TRUE);
@@ -132,7 +131,7 @@ ide_xml_parser_ui_start_element_sax_cb (ParserState    *state,
       node = ide_xml_symbol_node_new (string->str, NULL, "object", IDE_SYMBOL_KIND_UI_OBJECT);
       g_object_set (node, "use-markup", TRUE, NULL);
     }
-  else if (dzl_str_equal0 (name, "template"))
+  else if (ide_str_equal0 (name, "template"))
     {
       value = get_attribute (attributes, "class", "?");
       label = ide_xml_parser_get_color_tag (self, "class", COLOR_TAG_CLASS, TRUE, TRUE, TRUE);
@@ -148,15 +147,15 @@ ide_xml_parser_ui_start_element_sax_cb (ParserState    *state,
       node = ide_xml_symbol_node_new (string->str, NULL, (const gchar *)name, IDE_SYMBOL_KIND_UI_TEMPLATE);
       g_object_set (node, "use-markup", TRUE, NULL);
     }
-  else if (dzl_str_equal0 (name, "packing"))
+  else if (ide_str_equal0 (name, "packing"))
     {
       node = ide_xml_symbol_node_new ("packing", NULL, "packing", IDE_SYMBOL_KIND_UI_PACKING);
     }
-  else if (dzl_str_equal0 (name, "style"))
+  else if (ide_str_equal0 (name, "style"))
     {
       node = ide_xml_symbol_node_new ("style", NULL, "style", IDE_SYMBOL_KIND_UI_STYLE);
     }
-  else if (dzl_str_equal0 (name, "menu"))
+  else if (ide_str_equal0 (name, "menu"))
     {
       value = get_attribute (attributes, "id", "?");
       label = ide_xml_parser_get_color_tag (self, "id", COLOR_TAG_ID, TRUE, TRUE, TRUE);
@@ -166,7 +165,7 @@ ide_xml_parser_ui_start_element_sax_cb (ParserState    *state,
       node = ide_xml_symbol_node_new (string->str, NULL, "menu", IDE_SYMBOL_KIND_UI_MENU);
       g_object_set (node, "use-markup", TRUE, NULL);
     }
-  else if (dzl_str_equal0 (name, "submenu"))
+  else if (ide_str_equal0 (name, "submenu"))
     {
       value = get_attribute (attributes, "id", "?");
       label = ide_xml_parser_get_color_tag (self, "id", COLOR_TAG_ID, TRUE, TRUE, TRUE);
@@ -176,7 +175,7 @@ ide_xml_parser_ui_start_element_sax_cb (ParserState    *state,
       node = ide_xml_symbol_node_new (string->str, NULL, "submenu", IDE_SYMBOL_KIND_UI_SUBMENU);
       g_object_set (node, "use-markup", TRUE, NULL);
     }
-  else if (dzl_str_equal0 (name, "section"))
+  else if (ide_str_equal0 (name, "section"))
     {
       value = get_attribute (attributes, "id", "?");
       label = ide_xml_parser_get_color_tag (self, "id", COLOR_TAG_ID, TRUE, TRUE, TRUE);
@@ -186,7 +185,7 @@ ide_xml_parser_ui_start_element_sax_cb (ParserState    *state,
       node = ide_xml_symbol_node_new (string->str, NULL, "section", IDE_SYMBOL_KIND_UI_SECTION);
       g_object_set (node, "use-markup", TRUE, NULL);
     }
-  else if (dzl_str_equal0 (name, "item"))
+  else if (ide_str_equal0 (name, "item"))
     {
       node = ide_xml_symbol_node_new ("item", NULL, "item", IDE_SYMBOL_KIND_UI_ITEM);
     }
@@ -209,7 +208,7 @@ get_menu_attribute_value (IdeXmlSymbolNode *node,
     {
       child = IDE_XML_SYMBOL_NODE (ide_xml_symbol_node_get_nth_internal_child (node, i));
       if (ide_symbol_node_get_kind (IDE_SYMBOL_NODE (child)) == IDE_SYMBOL_KIND_UI_MENU_ATTRIBUTE &&
-          dzl_str_equal0 (ide_symbol_node_get_name (IDE_SYMBOL_NODE (child)), name))
+          ide_str_equal0 (ide_symbol_node_get_name (IDE_SYMBOL_NODE (child)), name))
         {
           return ide_xml_symbol_node_get_value (child);
         }
@@ -240,7 +239,7 @@ node_post_processing_collect_style_classes (IdeXmlParser      *self,
       if (ide_symbol_node_get_kind (IDE_SYMBOL_NODE (child)) == IDE_SYMBOL_KIND_UI_STYLE_CLASS)
         {
           name = ide_symbol_node_get_name (IDE_SYMBOL_NODE (child));
-          if (dzl_str_empty0 (name))
+          if (ide_str_empty0 (name))
             continue;
 
           class_tag = ide_xml_parser_get_color_tag (self, name, COLOR_TAG_STYLE_CLASS, TRUE, TRUE, TRUE);
@@ -308,11 +307,11 @@ ide_xml_parser_ui_post_processing (IdeXmlParser      *self,
 
       element_name = ide_xml_symbol_node_get_element_name (node);
 
-      if (dzl_str_equal0 (element_name, "style"))
+      if (ide_str_equal0 (element_name, "style"))
         node_post_processing_collect_style_classes (self, node);
-      else if (dzl_str_equal0 (element_name, "item") ||
-               dzl_str_equal0 (element_name, "submenu") ||
-               dzl_str_equal0 (element_name, "section"))
+      else if (ide_str_equal0 (element_name, "item") ||
+               ide_str_equal0 (element_name, "submenu") ||
+               ide_str_equal0 (element_name, "section"))
         node_post_processing_add_label (self, node);
     }
 
diff --git a/src/plugins/xml-pack/ide-xml-parser.c b/src/plugins/xml-pack/ide-xml-parser.c
index 57fdbc7d3..3d8d8abe1 100644
--- a/src/plugins/xml-pack/ide-xml-parser.c
+++ b/src/plugins/xml-pack/ide-xml-parser.c
@@ -18,7 +18,6 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
-#include <dazzle.h>
 #include <glib/gi18n.h>
 #include <glib-object.h>
 
@@ -207,7 +206,7 @@ ide_xml_parser_state_processing (IdeXmlParser          *self,
     {
       erroneous_element_name = ide_xml_symbol_node_get_element_name (state->parent_node);
       /* TODO: we need better node comparaison (ns) here */
-      if (!dzl_str_equal0 (erroneous_element_name, element_name))
+      if (!ide_str_equal0 (erroneous_element_name, element_name))
         {
           if (ide_xml_stack_is_empty (state->stack))
             goto error;
@@ -250,7 +249,7 @@ ide_xml_parser_state_processing (IdeXmlParser          *self,
                 goto error;
 
               popped_node = ide_xml_stack_pop (state->stack, &popped_element_name, &parent_node, &depth);
-              if (dzl_str_equal0 (popped_element_name, element_name))
+              if (ide_str_equal0 (popped_element_name, element_name))
                 {
                   ide_xml_symbol_node_set_end_tag_location (popped_node,
                                                             start_line, start_line_offset,
@@ -452,7 +451,7 @@ ide_xml_parser_internal_subset_sax_cb (ParserState   *state,
   g_assert (state != NULL);
   g_assert (IDE_IS_XML_PARSER (state->self));
 
-  if (dzl_str_empty0 ((gchar *)external_id) || dzl_str_empty0 ((gchar *)system_id))
+  if (ide_str_empty0 ((gchar *)external_id) || ide_str_empty0 ((gchar *)system_id))
     return;
 
   entry = ide_xml_schema_cache_entry_new ();
@@ -510,9 +509,9 @@ ide_xml_parser_processing_instruction_sax_cb (ParserState   *state,
       if (NULL != (extension = strrchr (schema_url, '.')))
         {
           ++extension;
-          if (dzl_str_equal0 (extension, "rng"))
+          if (ide_str_equal0 (extension, "rng"))
             kind = SCHEMA_KIND_RNG;
-          else if (dzl_str_equal0 (extension, "xsd"))
+          else if (ide_str_equal0 (extension, "xsd"))
             kind = SCHEMA_KIND_XML_SCHEMA;
           else
             goto fail;
@@ -708,7 +707,7 @@ ide_xml_parser_get_color_tag (IdeXmlParser *self,
 
   g_assert (IDE_IS_XML_PARSER (self));
   g_assert (self->color_tags != NULL);
-  g_assert (!dzl_str_empty0 (str));
+  g_assert (!ide_str_empty0 (str));
 
   tag = &g_array_index (self->color_tags, ColorTag, id);
   return g_strdup_printf ("%s<span foreground=\"%s\" background=\"%s\">%s%s%s</span>%s",
@@ -796,7 +795,7 @@ editor_settings_changed_cb (IdeXmlParser *self,
 {
   g_assert (IDE_IS_XML_PARSER (self));
 
-  if (dzl_str_equal0 (key, "style-scheme-name"))
+  if (ide_str_equal0 (key, "style-scheme-name"))
     init_color_tags (self);
 }
 
diff --git a/src/plugins/xml-pack/ide-xml-position.c b/src/plugins/xml-pack/ide-xml-position.c
index e2e98c078..ecea8de01 100644
--- a/src/plugins/xml-pack/ide-xml-position.c
+++ b/src/plugins/xml-pack/ide-xml-position.c
@@ -18,8 +18,6 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
-#include <dazzle.h>
-
 #include "ide-xml-position.h"
 
 G_DEFINE_BOXED_TYPE (IdeXmlPosition, ide_xml_position, ide_xml_position_ref, ide_xml_position_unref)
@@ -42,13 +40,13 @@ ide_xml_position_new (IdeXmlSymbolNode     *node,
 
   self->node = (IDE_IS_XML_SYMBOL_NODE (node)) ? g_object_ref (node) : NULL;
 
-  if (!dzl_str_empty0 (prefix))
+  if (!ide_str_empty0 (prefix))
     self->prefix = g_strdup (prefix);
 
-  if (!dzl_str_empty0 (detail_name))
+  if (!ide_str_empty0 (detail_name))
     self->detail_name = g_strdup (detail_name);
 
-  if (!dzl_str_empty0 (detail_value))
+  if (!ide_str_empty0 (detail_value))
     self->detail_value = g_strdup (detail_value);
 
   self->kind = kind;
diff --git a/src/plugins/xml-pack/ide-xml-proposal.c b/src/plugins/xml-pack/ide-xml-proposal.c
index 74a1eb808..ec0f16f99 100644
--- a/src/plugins/xml-pack/ide-xml-proposal.c
+++ b/src/plugins/xml-pack/ide-xml-proposal.c
@@ -34,7 +34,7 @@ struct _IdeXmlProposal
 };
 
 G_DEFINE_FINAL_TYPE_WITH_CODE (IdeXmlProposal, ide_xml_proposal, G_TYPE_OBJECT,
-                         G_IMPLEMENT_INTERFACE (IDE_TYPE_COMPLETION_PROPOSAL, NULL))
+                               G_IMPLEMENT_INTERFACE (GTK_SOURCE_TYPE_COMPLETION_PROPOSAL, NULL))
 
 static void
 ide_xml_proposal_finalize (GObject *object)
diff --git a/src/plugins/xml-pack/ide-xml-rng-define.c b/src/plugins/xml-pack/ide-xml-rng-define.c
index e8d2ef2cf..e35363416 100644
--- a/src/plugins/xml-pack/ide-xml-rng-define.c
+++ b/src/plugins/xml-pack/ide-xml-rng-define.c
@@ -18,8 +18,6 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
-#include <dazzle.h>
-
 #include "ide-xml-rng-define.h"
 
 G_DEFINE_BOXED_TYPE (IdeXmlRngDefine, ide_xml_rng_define, ide_xml_rng_define_ref, ide_xml_rng_define_unref)
@@ -248,12 +246,12 @@ ide_xml_rng_define_is_nameclass_match (IdeXmlRngDefine  *define,
   name = ide_xml_symbol_node_get_element_name (node);
   namespace = ide_xml_symbol_node_get_namespace (node);
 
-  if (define->name != NULL && !dzl_str_equal0 (name, define->name))
+  if (define->name != NULL && !ide_str_equal0 (name, define->name))
     return FALSE;
 
-  if (!dzl_str_empty0 ((const gchar *)define->ns))
+  if (!ide_str_empty0 ((const gchar *)define->ns))
     {
-      if (namespace == NULL || !dzl_str_equal0 (define->ns, namespace))
+      if (namespace == NULL || !ide_str_equal0 (define->ns, namespace))
         return FALSE;
     }
   else if (namespace != NULL && (define->name != NULL || define->ns != NULL))
diff --git a/src/plugins/xml-pack/ide-xml-rng-parser.c b/src/plugins/xml-pack/ide-xml-rng-parser.c
index 30f80b97a..173f22b50 100644
--- a/src/plugins/xml-pack/ide-xml-rng-parser.c
+++ b/src/plugins/xml-pack/ide-xml-rng-parser.c
@@ -23,7 +23,6 @@
  * Whole refactoring to match the GNOME Builder needs.
  */
 
-#include <dazzle.h>
 #include <libxml/tree.h>
 #include <libxml/uri.h>
 
@@ -164,8 +163,8 @@ is_valid_rng_node (xmlNode     *node,
   return (node != NULL &&
           node->ns != NULL &&
           node->type == XML_ELEMENT_NODE &&
-          dzl_str_equal0 (node->name, name) &&
-          dzl_str_equal0 (node->ns->href, xmlRelaxNGNs));
+          ide_str_equal0 (node->name, name) &&
+          ide_str_equal0 (node->ns->href, xmlRelaxNGNs));
 }
 
 static inline gboolean
@@ -223,7 +222,7 @@ static gint
 compare_href_func (XmlDocument *xml_doc,
                    gchar       *href)
 {
-  return !dzl_str_equal0 (href, xml_doc->href);
+  return !ide_str_equal0 (href, xml_doc->href);
 }
 
 static XmlDocument *
@@ -286,7 +285,7 @@ ide_xml_remove_redefine (IdeXmlRngParser *self,
 
           if (name_tmp != NULL)
             {
-              if (dzl_str_equal0 (name, name_tmp))
+              if (ide_str_equal0 (name, name_tmp))
                 remove_node (node);
             }
         }
@@ -296,7 +295,7 @@ ide_xml_remove_redefine (IdeXmlRngParser *self,
           if (inc_doc != NULL &&
               inc_doc->doc != NULL &&
               inc_doc->doc->children != NULL &&
-              dzl_str_equal0 (inc_doc->doc->children->name, "grammar"))
+              ide_str_equal0 (inc_doc->doc->children->name, "grammar"))
             {
               inc_root = xmlDocGetRootElement (inc_doc->doc);
               ide_xml_remove_redefine (self, inc_root->children, name);
@@ -319,7 +318,7 @@ load_include (IdeXmlRngParser *self,
 
   g_assert (IDE_IS_XML_RNG_PARSER (self));
   g_assert (node != NULL);
-  g_assert (!dzl_str_empty0 (url));
+  g_assert (!ide_str_empty0 (url));
 
   if (NULL != (xml_include_docs_stack_lookup (self, url)) ||
       NULL == (ns = get_node_closest_ns (node)) ||
@@ -378,7 +377,7 @@ load_externalref (IdeXmlRngParser *self,
 
   g_assert (IDE_IS_XML_RNG_PARSER (self));
   g_assert (node != NULL);
-  g_assert (!dzl_str_empty0 (url));
+  g_assert (!ide_str_empty0 (url));
 
   if (NULL != (xml_externalref_docs_stack_lookup (self, url)) ||
       NULL == (ns = get_node_closest_ns (node)) ||
@@ -427,14 +426,14 @@ ide_xml_rng_parser_cleanup (IdeXmlRngParser *self,
 
       if (current->type == XML_ELEMENT_NODE)
         {
-          if (current->ns == NULL || !dzl_str_equal0 (current->ns->href, xmlRelaxNGNs))
+          if (current->ns == NULL || !ide_str_equal0 (current->ns->href, xmlRelaxNGNs))
             {
               delete = current;
               goto next_node;
             }
           else
             {
-              if (dzl_str_equal0 (current->name, "externalRef"))
+              if (ide_str_equal0 (current->name, "externalRef"))
                 {
                   if (NULL == (href_url = build_url (root->doc, current)) ||
                       NULL == (ext_doc = load_externalref (self, current, (const gchar *)href_url)))
@@ -445,7 +444,7 @@ ide_xml_rng_parser_cleanup (IdeXmlRngParser *self,
 
                   current->psvi = ext_doc;
                 }
-              else if (dzl_str_equal0 (current->name, "include"))
+              else if (ide_str_equal0 (current->name, "include"))
                 {
                   if (NULL == (href_url = build_url (root->doc, current)) ||
                       NULL == (ext_doc = load_include (self, current, (const gchar *)href_url)))
@@ -456,8 +455,8 @@ ide_xml_rng_parser_cleanup (IdeXmlRngParser *self,
 
                   current->psvi = ext_doc;
                 }
-              else if (dzl_str_equal0 (current->name, "element") ||
-                       dzl_str_equal0 (current->name, "attribute"))
+              else if (ide_str_equal0 (current->name, "element") ||
+                       ide_str_equal0 (current->name, "attribute"))
                 {
                   xmlNode *text_node;
                   xmlNode *doc_node;
@@ -480,13 +479,13 @@ ide_xml_rng_parser_cleanup (IdeXmlRngParser *self,
                       xmlUnsetProp (current, (const guchar *)"name");
                       if (NULL != (ns = xmlGetProp (current, NS_PROP)))
                         xmlSetProp (text_node, NS_PROP, ns);
-                      else if (dzl_str_equal0 (current->name, "attribute"))
+                      else if (ide_str_equal0 (current->name, "attribute"))
                         xmlSetProp (text_node, NS_PROP, (const guchar *)"");
                     }
                 }
-              else if (dzl_str_equal0 (current->name, "name") ||
-                       dzl_str_equal0 (current->name, "nsname") ||
-                       dzl_str_equal0 (current->name, "value"))
+              else if (ide_str_equal0 (current->name, "name") ||
+                       ide_str_equal0 (current->name, "nsname") ||
+                       ide_str_equal0 (current->name, "value"))
                 {
                   if (xmlHasProp (current, NS_PROP) == NULL)
                     {
@@ -508,7 +507,7 @@ ide_xml_rng_parser_cleanup (IdeXmlRngParser *self,
                         xmlSetProp (current, NS_PROP, ns);
                     }
 
-                  if (dzl_str_equal0 (current->name, "name"))
+                  if (ide_str_equal0 (current->name, "name"))
                     {
                       g_autoxmlfree guchar *name = NULL;
                       g_autoxmlfree guchar *local = NULL;
@@ -527,18 +526,18 @@ ide_xml_rng_parser_cleanup (IdeXmlRngParser *self,
                         }
                     }
                 }
-              else if (dzl_str_equal0 (current->name, "except") && current != root)
+              else if (ide_str_equal0 (current->name, "except") && current != root)
                 {
                     if (current->parent != NULL &&
-                        (dzl_str_equal0 (current->parent->name, "anyName") ||
-                         dzl_str_equal0 (current->parent->name, "nsName")))
+                        (ide_str_equal0 (current->parent->name, "anyName") ||
+                         ide_str_equal0 (current->parent->name, "nsName")))
                       {
                         ide_xml_rng_parser_cleanup (self, current);
                         goto next_node;
                       }
                 }
 
-              if (dzl_str_equal0 (current->name, "div"))
+              if (ide_str_equal0 (current->name, "div"))
                 {
                   g_autoxmlfree guchar *ns = NULL;
                   xmlNode *child;
@@ -581,8 +580,8 @@ ide_xml_rng_parser_cleanup (IdeXmlRngParser *self,
             {
               if (current->parent != NULL && current->parent->type == XML_ELEMENT_NODE)
                 {
-                  if (!dzl_str_equal0 (current->parent->name, "value") &&
-                      !dzl_str_equal0 (current->parent->name, "param"))
+                  if (!ide_str_equal0 (current->parent->name, "value") &&
+                      !ide_str_equal0 (current->parent->name, "param"))
                     delete = current;
                 }
               else
@@ -1100,7 +1099,7 @@ parse_pattern (IdeXmlRngParser *self,
   else if (is_valid_rng_node (node, "ref"))
     {
       name = _strip (xmlGetProp (node, (const guchar *)"name"));
-      if (!dzl_str_empty0 ((gchar *)name))
+      if (!ide_str_empty0 ((gchar *)name))
         {
           def = ide_xml_rng_define_new (node, parent, name, IDE_XML_RNG_DEFINE_REF);
           ide_xml_hash_table_add (self->grammars->refs, (gchar *)def->name, ide_xml_rng_define_ref (def));
@@ -1415,7 +1414,7 @@ parse_include (IdeXmlRngParser *self,
 
   if (NULL != (include = node->psvi) &&
       NULL != (root = xmlDocGetRootElement(include->doc)) &&
-      dzl_str_equal0 (root->name, "grammar") &&
+      ide_str_equal0 (root->name, "grammar") &&
       root->children != NULL)
     {
       parse_grammar_content (self, root->children);
@@ -1445,16 +1444,16 @@ merge_starts (IdeXmlRngParser  *self,
       combine = NULL;
       if (current->node != NULL &&
           current->node->parent != NULL &&
-          dzl_str_equal0 (current->node->parent->name, "start"))
+          ide_str_equal0 (current->node->parent->name, "start"))
         {
           if (NULL != (combine = xmlGetProp(current->node->parent, (const guchar *)"combine")))
             {
-              if (dzl_str_equal0 (combine, "choice"))
+              if (ide_str_equal0 (combine, "choice"))
                 {
                   if (combine_type == XML_RNG_COMBINE_UNDEF)
                     combine_type = XML_RNG_COMBINE_CHOICE;
                 }
-              else if (dzl_str_equal0 (combine, "interleave"))
+              else if (ide_str_equal0 (combine, "interleave"))
                 {
                   if (combine_type == XML_RNG_COMBINE_UNDEF)
                     combine_type = XML_RNG_COMBINE_INTERLEAVE;
@@ -1506,12 +1505,12 @@ merge_defines_func (const gchar *name,
       current = g_ptr_array_index (array, i);
       if (NULL != (combine = xmlGetProp(current->node, (const guchar *)"combine")))
         {
-          if (dzl_str_equal0 (combine, "choice"))
+          if (ide_str_equal0 (combine, "choice"))
             {
               if (combine_type == XML_RNG_COMBINE_UNDEF)
                 combine_type = XML_RNG_COMBINE_CHOICE;
             }
-          else if (dzl_str_equal0 (combine, "interleave"))
+          else if (ide_str_equal0 (combine, "interleave"))
             {
               if (combine_type == XML_RNG_COMBINE_UNDEF)
                 combine_type = XML_RNG_COMBINE_INTERLEAVE;
diff --git a/src/plugins/xml-pack/ide-xml-stack.c b/src/plugins/xml-pack/ide-xml-stack.c
index c93566448..5e612724c 100644
--- a/src/plugins/xml-pack/ide-xml-stack.c
+++ b/src/plugins/xml-pack/ide-xml-stack.c
@@ -18,7 +18,6 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
-#include <dazzle.h>
 #include <libide-code.h>
 
 #include "ide-xml-stack.h"
@@ -56,7 +55,7 @@ ide_xml_stack_push (IdeXmlStack       *self,
   StackItem item;
 
   g_return_if_fail (IDE_IS_XML_STACK (self));
-  g_return_if_fail (!dzl_str_empty0 (name));
+  g_return_if_fail (!ide_str_empty0 (name));
   g_return_if_fail (IDE_IS_XML_SYMBOL_NODE (node) || node == NULL);
   g_return_if_fail (IDE_IS_XML_SYMBOL_NODE (parent) || parent == NULL);
 
diff --git a/src/plugins/xml-pack/ide-xml-tree-builder-utils.c 
b/src/plugins/xml-pack/ide-xml-tree-builder-utils.c
index 4b10d9894..48be86c36 100644
--- a/src/plugins/xml-pack/ide-xml-tree-builder-utils.c
+++ b/src/plugins/xml-pack/ide-xml-tree-builder-utils.c
@@ -18,7 +18,6 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
-#include <dazzle.h>
 #include <string.h>
 
 #include "ide-xml-tree-builder-utils-private.h"
@@ -31,14 +30,14 @@ list_get_attribute (const guchar **attributes,
 {
   const guchar **l = attributes;
 
-  g_return_val_if_fail (!dzl_str_empty0 (name), NULL);
+  g_return_val_if_fail (!ide_str_empty0 (name), NULL);
 
   if (attributes == NULL)
     return NULL;
 
   while (l [0] != NULL)
     {
-      if (dzl_str_equal0 (name, l [0]))
+      if (ide_str_equal0 (name, l [0]))
         return (const gchar *)l [1];
 
       l += 2;
diff --git a/src/plugins/xml-pack/ide-xml-tree-builder.c b/src/plugins/xml-pack/ide-xml-tree-builder.c
index 90069737c..0ddde1df6 100644
--- a/src/plugins/xml-pack/ide-xml-tree-builder.c
+++ b/src/plugins/xml-pack/ide-xml-tree-builder.c
@@ -18,8 +18,10 @@
  * SPDX-License-Identifier: GPL-3.0-or-later
  */
 
+#define G_LOG_DOMAIN "ide-xml-tree-builder"
+
+#include "config.h"
 
-#include <dazzle.h>
 #include <glib/gi18n.h>
 #include <libxml/parser.h>
 #include <string.h>
@@ -141,14 +143,14 @@ fetch_schemas_cb (GObject      *object,
                   GAsyncResult *result,
                   gpointer      user_data)
 {
-  DzlTaskCache *schemas_cache = (DzlTaskCache *)object;
+  IdeTaskCache *schemas_cache = (IdeTaskCache *)object;
   g_autoptr(FetchSchemasState) state = user_data;
   g_autoptr(IdeXmlSchemaCacheEntry) cache_entry = NULL;
   IdeXmlSchemaCacheEntry *entry;
   g_autoptr(GError) error = NULL;
   guint *count;
 
-  g_assert (DZL_IS_TASK_CACHE (schemas_cache));
+  g_assert (IDE_IS_TASK_CACHE (schemas_cache));
   g_assert (G_IS_ASYNC_RESULT (result));
   g_assert (state != NULL);
   g_assert (IDE_IS_TASK (state->task));
@@ -157,7 +159,7 @@ fetch_schemas_cb (GObject      *object,
   g_assert (state->index < state->schemas->len);
 
   entry = g_ptr_array_index (state->schemas, state->index);
-  cache_entry = dzl_task_cache_get_finish (schemas_cache, result, &error);
+  cache_entry = ide_task_cache_get_finish (schemas_cache, result, &error);
 
   if (cache_entry != NULL)
     {
@@ -205,7 +207,7 @@ fetch_schemas_async (IdeXmlTreeBuilder   *self,
   g_autoptr(IdeTask) task = NULL;
   g_autoptr(GPtrArray) schemas_copy = NULL;
   IdeXmlService *service;
-  DzlTaskCache *schemas_cache;
+  IdeTaskCache *schemas_cache;
   IdeContext *context;
   guint *count = 0;
 
@@ -251,7 +253,7 @@ fetch_schemas_async (IdeXmlTreeBuilder   *self,
       state->index = schemas_copy->len - 1;
 
       /* TODO: peek schemas if it's already in cache */
-      dzl_task_cache_get_async (schemas_cache,
+      ide_task_cache_get_async (schemas_cache,
                                 entry->file,
                                 FALSE,
                                 cancellable,
diff --git a/src/plugins/xml-pack/meson.build b/src/plugins/xml-pack/meson.build
index 1137fdcaa..08986e341 100644
--- a/src/plugins/xml-pack/meson.build
+++ b/src/plugins/xml-pack/meson.build
@@ -4,11 +4,11 @@ plugins_sources += files([
   'ide-xml-analysis.c',
   'ide-xml-completion-attributes.c',
   'ide-xml-completion-values.c',
-  'ide-xml-completion-provider.c',
+  # 'ide-xml-completion-provider.c',
   'ide-xml-diagnostic-provider.c',
   'ide-xml-hash-table.c',
   'ide-xml-highlighter.c',
-  'ide-xml-indenter.c',
+  # 'ide-xml-indenter.c',
   'ide-xml-parser.c',
   'ide-xml-parser-generic.c',
   'ide-xml-parser-ui.c',
diff --git a/src/plugins/xml-pack/xml-pack-plugin.c b/src/plugins/xml-pack/xml-pack-plugin.c
index d2c8fb037..097c7aa1b 100644
--- a/src/plugins/xml-pack/xml-pack-plugin.c
+++ b/src/plugins/xml-pack/xml-pack-plugin.c
@@ -21,6 +21,7 @@
 #include "config.h"
 
 #include <libpeas/peas.h>
+
 #include <libide-code.h>
 #include <libide-sourceview.h>
 
@@ -33,18 +34,22 @@
 _IDE_EXTERN void
 _ide_xml_register_types (PeasObjectModule *module)
 {
+#if 0
   peas_object_module_register_extension_type (module,
-                                              IDE_TYPE_COMPLETION_PROVIDER,
+                                              GTK_SOURCE_TYPE_COMPLETION_PROVIDER,
                                               IDE_TYPE_XML_COMPLETION_PROVIDER);
+#endif
   peas_object_module_register_extension_type (module,
                                               IDE_TYPE_DIAGNOSTIC_PROVIDER,
                                               IDE_TYPE_XML_DIAGNOSTIC_PROVIDER);
   peas_object_module_register_extension_type (module,
                                               IDE_TYPE_HIGHLIGHTER,
                                               IDE_TYPE_XML_HIGHLIGHTER);
+#if 0
   peas_object_module_register_extension_type (module,
-                                              IDE_TYPE_INDENTER,
+                                              GTK_SOURCE_TYPE_INDENTER,
                                               IDE_TYPE_XML_INDENTER);
+#endif
   peas_object_module_register_extension_type (module,
                                               IDE_TYPE_SYMBOL_RESOLVER,
                                               IDE_TYPE_XML_SYMBOL_RESOLVER);


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/plugins/xml-pack/ide-xml-service.c b/src/plugins/xml-pack/ide-xml-service.c
index 1e29a4e59..04158110b 100644
--- a/src/plugins/xml-pack/ide-xml-service.c
+++ b/src/plugins/xml-pack/ide-xml-service.c
@@ -39,8 +39,8 @@ struct _IdeXmlService
 {
   IdeObject          parent_instance;
 
-  DzlTaskCache      *analyses;
-  DzlTaskCache      *schemas;
+  IdeTaskCache      *analyses;
+  IdeTaskCache      *schemas;
   IdeXmlTreeBuilder *tree_builder;
   GCancellable      *cancellable;
 };
@@ -68,7 +68,7 @@ ide_xml_service_build_tree_cb2 (GObject      *object,
 }
 
 static void
-ide_xml_service_build_tree_cb (DzlTaskCache  *cache,
+ide_xml_service_build_tree_cb (IdeTaskCache  *cache,
                                gconstpointer  key,
                                GTask         *task,
                                gpointer       user_data)
@@ -78,7 +78,7 @@ ide_xml_service_build_tree_cb (DzlTaskCache  *cache,
 
   IDE_ENTRY;
 
-  g_assert (DZL_IS_TASK_CACHE (cache));
+  g_assert (IDE_IS_TASK_CACHE (cache));
   g_assert (IDE_IS_XML_SERVICE (self));
   g_assert (G_IS_FILE (file));
   g_assert (G_IS_TASK (task));
@@ -209,7 +209,7 @@ ide_xml_service_load_schema_cb2 (GObject      *object,
 
 /* Get mtime phase */
 static void
-ide_xml_service_load_schema_cb (DzlTaskCache  *cache,
+ide_xml_service_load_schema_cb (IdeTaskCache  *cache,
                                 gconstpointer  key,
                                 GTask         *task,
                                 gpointer       user_data)
@@ -220,7 +220,7 @@ ide_xml_service_load_schema_cb (DzlTaskCache  *cache,
 
   IDE_ENTRY;
 
-  g_assert (DZL_IS_TASK_CACHE (cache));
+  g_assert (IDE_IS_TASK_CACHE (cache));
   g_assert (IDE_IS_XML_SERVICE (self));
   g_assert (G_IS_TASK (task));
   g_assert (G_IS_FILE (file));
@@ -248,12 +248,12 @@ ide_xml_service_get_analysis_cb (GObject      *object,
                                  GAsyncResult *result,
                                  gpointer      user_data)
 {
-  DzlTaskCache *cache = (DzlTaskCache *)object;
+  IdeTaskCache *cache = (IdeTaskCache *)object;
   g_autoptr(GTask) task = user_data;
   g_autoptr(IdeXmlAnalysis) analysis = NULL;
   g_autoptr(GError) error = NULL;
 
-  g_assert (DZL_IS_TASK_CACHE (cache));
+  g_assert (IDE_IS_TASK_CACHE (cache));
   g_assert (G_IS_ASYNC_RESULT (result));
   g_assert (G_IS_TASK (task));
 
@@ -1106,11 +1106,11 @@ ide_xml_service_get_cached_diagnostics (IdeXmlService *self,
 /**
  * ide_xml_service_get_schemas_cache:
  *
  * Gets the #DzlTaskCache for the xml schemas.
  *
- * Returns: (transfer NULL): a #DzlTaskCache.
+ * Returns: (transfer NULL): a #IdeTaskCache.
  */
-DzlTaskCache *
+IdeTaskCache *
 ide_xml_service_get_schemas_cache (IdeXmlService *self)
 {
   g_return_val_if_fail (IDE_IS_XML_SERVICE (self), NULL);
@@ -1106,11 +1106,11 @@ ide_xml_service_get_cached_diagnostics (IdeXmlService *self,
  * ide_xml_service_get_schemas_cache:
  *
- * Gets the #DzlTaskCache for the xml schemas.
+ * Gets the #IdeTaskCache for the xml schemas.
  *